pub trait PrimeSetBasics {
    fn expand(&mut self);
    fn list(&self) -> &[u64];
}

Required Methods

Finds one more prime, and adds it to the list

Return all primes found so far as a slice

Implementors