pub struct Sieve { /* private fields */ }Expand description
A prime generator, using the Sieve of Eratosthenes method. This is asymptotically more efficient than the Trial Division method, but slower earlier on.
Create with let mut pset = Sieve::new(), and then use pset.iter() to iterate over all primes.
Implementations